==> airbridge_flutter_sdk-2.0.1.tar.gz: ios/Classes/PlacementAPI.swift <==
//
//  PlacementAPI.swift
//  airbridge_flutter_sdk
//
//  Created by WOF on 2021/07/05.
//

import Foundation
import AirBridge

struct PlacementAPI {
    let channel: FlutterMethodChannel
}

extension PlacementAPI {
    mutating func attachToChannel() {
        channel.setMethodCallHandler(handle(call:result:))
    }
    
    mutating func detachFromChannel() {
        channel.setMethodCallHandler(nil)
    }
}

extension PlacementAPI {
    func handle(call: FlutterMethodCall, result: FlutterResult) {
        let arguments = call.arguments as? [AnyHashable: Any] ?? [:]
        
        switch call.method {
        case "click": click(arguments, result)
        case "impression": impression(arguments, result)
        default: result(FlutterMethodNotImplemented)
        }
    }
}

extension PlacementAPI {
    func click(_ arguments: [AnyHashable: Any], _ result: FlutterResult) {
        if let trackingLink = arguments["trackingLink"] as? String {
            AirBridge.placement().click(trackingLink,
                                        deeplink: arguments["deeplink"] as? String,
                                        fallback: arguments["fallback"] as? String)
        }
        
        result(nil)
    }
    
    func impression(_ arguments: [AnyHashable: Any], _ result: FlutterResult) {
        if let trackingLink = arguments["trackingLink"] as? String {
            AirBridge.placement().impression(trackingLink)
        }
        
        result(nil)
    }
}

extension PlacementAPI {
    static func fromPlugin(_ registrar: FlutterPluginRegistrar) -> PlacementAPI {
        return PlacementAPI(channel: FlutterMethodChannel(name: "airbridge_flutter_sdk/method/placement",
                                                          binaryMessenger: registrar.messenger()))
    }
}

==> airbridge_flutter_sdk-3.1.2.tar.gz: ios/Classes/PlacementAPI.swift <==
//
//  PlacementAPI.swift
//  airbridge_flutter_sdk
//
//  Created by WOF on 2021/07/05.
//

import Foundation
import AirBridge

struct PlacementAPI {
    let channel: FlutterMethodChannel
}

extension PlacementAPI {
    mutating func attachToChannel() {
        channel.setMethodCallHandler(handle(call:result:))
    }
    
    mutating func detachFromChannel() {
        channel.setMethodCallHandler(nil)
    }
}

extension PlacementAPI {
    func handle(call: FlutterMethodCall, result: FlutterResult) {
        let arguments = call.arguments as? [AnyHashable: Any] ?? [:]
        
        switch call.method {
        case "click": click(arguments, result)
        case "impression": impression(arguments, result)
        default: result(FlutterMethodNotImplemented)
        }
    }
}

extension PlacementAPI {
    func click(_ arguments: [AnyHashable: Any], _ result: FlutterResult) {
        if let trackingLink = arguments["trackingLink"] as? String {
            if let trackingLinkURL = URL(string: trackingLink) {
                AirBridge.placement().click(trackingLinkURL)
            }
        }

        result(nil)
    }

    func impression(_ arguments: [AnyHashable: Any], _ result: FlutterResult) {
        if let trackingLink = arguments["trackingLink"] as? String {
            if let trackingLinkURL = URL(string: trackingLink) {
                AirBridge.placement().impression(trackingLinkURL)
            }
        }

        result(nil)
    }
}

extension PlacementAPI {
    static func fromPlugin(_ registrar: FlutterPluginRegistrar) -> PlacementAPI {
        return PlacementAPI(channel: FlutterMethodChannel(name: "airbridge_flutter_sdk/method/placement",
                                                          binaryMessenger: registrar.messenger()))
    }
}
